# HelpMe-project
The project **HelpMe-Assistance** - is your personal CLI assistant. AddressBook, NoteBook, CleanFolder -  in one App.

## Table of contents
* [General info](#general-info)
* [Technologies](#technologies)
* [Setup](#setup)

## General info
This is a bot-assistant product. It propose tree functionality:
* **Address Book** - add new contacts to the phonebook, together with birthday, email and address information. Additional features: edit and delete contacts, announce the next birthdays.
* **Note Book** - add note together with their title and tags. Additional features: add new tags, search by tags and key values, edit and delete notes. 
* **Clean Folder** - sort all files in the chosen folder and redirect them to the corresponding type-folders.
	
## Technologies
Project is mainly based on:
* Python OOPs Concepts 
Utilised modules: 
* normalize, datetime, collections(UserDict)
* file_parser, pickle  
	
## Setup
To run this project, install the [helpme-assistance](https://pypi.org/project/helpme-assistance/) packaje locally using `pip` and run it using `helpme` command:

```
$ pip install helpme-assistance 
$ # or
$ pip3 install helpme-assistance
$ helpme
```
